/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.daypc.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.daypc.domain.DmDayPc;
import me.zhengjie.modules.dm.daypc.service.DmDayPcService;
import me.zhengjie.modules.dm.daypc.service.dto.DmDayPcQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author sunmz
* @date 2021-09-22
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "daypc管理")
@RequestMapping("/api/dmDayPc")
public class DmDayPcController {

    private final DmDayPcService dmDayPcService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmDayPc:list')")
    public void download(HttpServletResponse response, DmDayPcQueryCriteria criteria) throws IOException {
        dmDayPcService.download(dmDayPcService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询daypc")
    @ApiOperation("查询daypc")
    @PreAuthorize("@el.check('dmDayPc:list')")
    public ResponseEntity<Object> query(DmDayPcQueryCriteria criteria, Pageable pageable) throws Exception {
        return new ResponseEntity<>(dmDayPcService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增daypc")
    @ApiOperation("新增daypc")
    @PreAuthorize("@el.check('dmDayPc:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmDayPc resources) throws Exception {
        return new ResponseEntity<>(dmDayPcService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改daypc")
    @ApiOperation("修改daypc")
    @PreAuthorize("@el.check('dmDayPc:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmDayPc resources){
        dmDayPcService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除daypc")
    @ApiOperation("删除daypc")
    @PreAuthorize("@el.check('dmDayPc:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmDayPcService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }

    @GetMapping(value = "/foodRepository")
    @Log("今日菜品")
    @ApiOperation("今日菜品")
    public ResponseEntity<Object> foodRepository(){
        return new ResponseEntity<>(dmDayPcService.foodRepository(),HttpStatus.OK);
    }
}