/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.food.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.config.FileProperties;
import me.zhengjie.modules.dm.food.domain.DmFood;
import me.zhengjie.modules.dm.food.service.DmFoodService;
import me.zhengjie.modules.dm.food.service.dto.DmFoodQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author sunmz
* @date 2021-09-15
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "food管理")
@RequestMapping("/api/dmFood")
public class DmFoodController {

    private final DmFoodService dmFoodService;
    private final FileProperties properties;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmFood:list')")
    public void download(HttpServletResponse response, DmFoodQueryCriteria criteria) throws IOException {
        dmFoodService.download(dmFoodService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询food")
    @ApiOperation("查询food")
    @PreAuthorize("@el.check('dmFood:list')")
    public ResponseEntity<Object> query(DmFoodQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmFoodService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增food")
    @ApiOperation("新增food")
    @PreAuthorize("@el.check('dmFood:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmFood resources){
        return new ResponseEntity<>(dmFoodService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改food")
    @ApiOperation("修改food")
    @PreAuthorize("@el.check('dmFood:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmFood resources){
        dmFoodService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除food")
    @ApiOperation("删除food")
    @PreAuthorize("@el.check('dmFood:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmFoodService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}