/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.foodCate.service;

import me.zhengjie.modules.dm.foodCate.domain.DmFoodCate;
import me.zhengjie.modules.dm.foodCate.service.dto.DmFoodCateDto;
import me.zhengjie.modules.dm.foodCate.service.dto.DmFoodCateQueryCriteria;
import me.zhengjie.modules.system.domain.Menu;
import me.zhengjie.modules.system.service.dto.MenuDto;
import me.zhengjie.modules.system.service.dto.MenuQueryCriteria;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.Query;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
* @website https://el-admin.vip
* @description 服务接口
* @author sunmz
* @date 2021-09-15
**/
public interface DmFoodCateService {

    /**
    * 查询数据分页
    * @param criteria 条件
    * @param pageable 分页参数
    * @return Map<String,Object>
    */
    Map<String,Object> queryAll(DmFoodCateQueryCriteria criteria, Pageable pageable);

    /**
     * 查询全部数据
     * @param criteria 条件
     * @param isQuery /
     * @throws Exception /
     * @return /
     */
    Map<String,Object> queryAll(DmFoodCateQueryCriteria criteria, Boolean isQuery, Pageable pageable) throws Exception;

    /**
    * 查询所有数据不分页
    * @param criteria 条件参数
    * @return List<DmFoodDto>
    */
    List<DmFoodCateDto> queryAll(DmFoodCateQueryCriteria criteria);

    /**
     * 根据ID查询
     * @param id ID
     * @return DmFoodDto
     */
    DmFoodCateDto findById(Integer id);

    /**
     * 根据ID获取同级与上级数据
     * @param menuDto /
     * @param objects /
     * @return /
     */
    List<DmFoodCateDto> getSuperior(DmFoodCateDto menuDto, List<DmFoodCate> objects);

    /**
     * 构建菜单树
     * @param menuDtos 原始数据
     * @return /
     */
    List<DmFoodCateDto> buildTree(List<DmFoodCateDto> menuDtos);

    /**
    * 创建
    * @param resources /
    * @return DmFoodDto
    */
    void create(DmFoodCate resources);

    /**
    * 编辑
    * @param resources /
    */
    void update(DmFoodCate resources);

    /**
    * 多选删除
    * @param ids /
    */
    void deleteAll(Set<DmFoodCate> ids);

    List<DmFoodCateDto> getMenus(Integer pid);

    /**
     * 根据ID查询
     * @param id /
     * @return /
     */
    DmFoodCate findOne(Integer id);

    /**
     * 获取所有子节点，包含自身ID
     * @param menuList /
     * @param menuSet /
     * @return /
     */
    Set<DmFoodCate> getChildMenus(List<DmFoodCate> menuList, Set<DmFoodCate> menuSet);

    /**
    * 导出数据
    * @param all 待导出的数据
    * @param response /
    * @throws IOException /
    */
    void download(List<DmFoodCateDto> all, HttpServletResponse response) throws IOException;

}