/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.order.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.order.domain.DmOrderItem;
import me.zhengjie.modules.dm.order.service.DmOrderItemService;
import me.zhengjie.modules.dm.order.service.dto.DmOrderItemQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author sunmz
* @date 2021-09-15
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "orderItem管理")
@RequestMapping("/api/dmOrderItem")
public class DmOrderItemController {

    private final DmOrderItemService dmOrderItemService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmOrderItem:list')")
    public void download(HttpServletResponse response, DmOrderItemQueryCriteria criteria) throws IOException {
        dmOrderItemService.download(dmOrderItemService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询orderItem")
    @ApiOperation("查询orderItem")
    @PreAuthorize("@el.check('dmOrderItem:list')")
    public ResponseEntity<Object> query(DmOrderItemQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmOrderItemService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @GetMapping(value = "/queryDetails")
    @Log("查询orderItem")
    @ApiOperation("查询orderItem")
    public ResponseEntity<Object> queryDetails(DmOrderItemQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmOrderItemService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增orderItem")
    @ApiOperation("新增orderItem")
    @PreAuthorize("@el.check('dmOrderItem:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmOrderItem resources){
        return new ResponseEntity<>(dmOrderItemService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改orderItem")
    @ApiOperation("修改orderItem")
    @PreAuthorize("@el.check('dmOrderItem:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmOrderItem resources){
        dmOrderItemService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除orderItem")
    @ApiOperation("删除orderItem")
    @PreAuthorize("@el.check('dmOrderItem:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmOrderItemService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}