/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.rfidTableware.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.rfidTableware.domain.DmRfidTableware;
import me.zhengjie.modules.dm.rfidTableware.service.DmRfidTablewareService;
import me.zhengjie.modules.dm.rfidTableware.service.dto.DmRfidTablewareQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author sunmz
* @date 2021-09-15
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "rfidTableware管理")
@RequestMapping("/api/dmRfidTableware")
public class DmRfidTablewareController {

    private final DmRfidTablewareService dmRfidTablewareService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmRfidTableware:list')")
    public void download(HttpServletResponse response, DmRfidTablewareQueryCriteria criteria) throws IOException {
        dmRfidTablewareService.download(dmRfidTablewareService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询rfidTableware")
    @ApiOperation("查询rfidTableware")
    @PreAuthorize("@el.check('dmRfidTableware:list')")
    public ResponseEntity<Object> query(DmRfidTablewareQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmRfidTablewareService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增rfidTableware")
    @ApiOperation("新增rfidTableware")
    @PreAuthorize("@el.check('dmRfidTableware:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmRfidTableware resources){
        return new ResponseEntity<>(dmRfidTablewareService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改rfidTableware")
    @ApiOperation("修改rfidTableware")
    @PreAuthorize("@el.check('dmRfidTableware:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmRfidTableware resources){
        dmRfidTablewareService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除rfidTableware")
    @ApiOperation("删除rfidTableware")
    @PreAuthorize("@el.check('dmRfidTableware:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmRfidTablewareService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}