/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.service.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.service.domain.DmServicePj;
import me.zhengjie.modules.dm.service.service.DmServicePjService;
import me.zhengjie.modules.dm.service.service.dto.DmServicePjQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author sunmz
* @date 2021-09-15
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "servicePj管理")
@RequestMapping("/api/dmServicePj")
public class DmServicePjController {

    private final DmServicePjService dmServicePjService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmServicePj:list')")
    public void download(HttpServletResponse response, DmServicePjQueryCriteria criteria) throws IOException {
        dmServicePjService.download(dmServicePjService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询servicePj")
    @ApiOperation("查询servicePj")
    @PreAuthorize("@el.check('dmServicePj:list')")
    public ResponseEntity<Object> query(DmServicePjQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmServicePjService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增servicePj")
    @ApiOperation("新增servicePj")
    @PreAuthorize("@el.check('dmServicePj:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmServicePj resources){
        return new ResponseEntity<>(dmServicePjService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改servicePj")
    @ApiOperation("修改servicePj")
    @PreAuthorize("@el.check('dmServicePj:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmServicePj resources){
        dmServicePjService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @PutMapping(value = "/updatePj")
    @Log("修改状态")
    @ApiOperation("修改状态")
    public ResponseEntity<Object> updatePj(@Validated @RequestBody String resources){
        dmServicePjService.updatePj(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除servicePj")
    @ApiOperation("删除servicePj")
    @PreAuthorize("@el.check('dmServicePj:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Integer[] ids) {
        dmServicePjService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}